from setuptools import setup

setup(
    name = 'pyledshop',
    packages = ['pyledshop'],
    version = '0.0.1',
    description = 'A Python library to communicate with LED Shop compatible led strip controllers',
    author = 'blockarchitech',
    url = 'https://github.com/blockarchitech/pyledshop',
    license = 'MIT',
    keywords = [
        'led shop',
        'led strip',
        'light',
        'SP108E',
        ],
		classifiers=[
			    'Development Status :: 4 - Beta',
		]
)
